@@ -89,14 +89,16 @@ panel.histogram <-
              border = plot.polygon$border,
              lty = plot.polygon$lty,
              lwd = plot.polygon$lwd,
-             ...)
+             ...,
+             identifier = "histogram")
 {
     plot.polygon  <- trellis.par.get("plot.polygon")
 
     xscale <- current.panel.limits()$xlim
     panel.lines(x = xscale[1] + diff(xscale) * c(0.05, 0.95),
                 y = c(0,0),
-                col = border, lty = lty, lwd = lwd, alpha = alpha)
+                col = border, lty = lty, lwd = lwd, alpha = alpha,
+                identifier = paste(identifier, "baseline", sep = "."))
 ##     grid.lines(x = c(0.05, 0.95),
 ##                y = unit(c(0,0), "native"),
 ##                gp = gpar(col = border, lty = lty, lwd = lwd, alpha = alpha),
@@ -137,7 +139,8 @@ panel.histogram <-
                        col = col, alpha = alpha,
                        border = border, lty = lty,
                        lwd = lwd,
-                       just = c("left", "bottom"))
+                       just = c("left", "bottom"),
+                       identifier = identifier)
         }
     }
 }
@@ -194,6 +197,7 @@ histogram.formula <-
              ...,
              lattice.options = NULL,
              default.scales = list(),
+             default.prepanel = lattice.getOption("prepanel.default.histogram"),
              subscripts = !is.null(groups),
              subset = TRUE)
 {
@@ -222,12 +226,6 @@ histogram.formula <-
 
     if ("subscripts" %in% names(formals(panel))) subscripts <- TRUE
     if (subscripts) subscr <- form$subscr
-
-    prepanel <-
-        if (is.function(prepanel)) prepanel 
-        else if (is.character(prepanel)) get(prepanel)
-        else eval(prepanel)
-
     cond <- form$condition
     x <- form$right
     if (length(cond) == 0)
@@ -271,16 +269,16 @@ histogram.formula <-
     ## Step 3: Decide if limits were specified in call:
     
     have.xlim <- !missing(xlim)
-    if (!is.null(foo$x.scales$limit))
+    if (!is.null(foo$x.scales$limits))
     {
         have.xlim <- TRUE
-        xlim <- foo$x.scales$limit
+        xlim <- foo$x.scales$limits
     }
     have.ylim <- !missing(ylim)
-    if (!is.null(foo$y.scales$limit))
+    if (!is.null(foo$y.scales$limits))
     {
         have.ylim <- TRUE
-        ylim <- foo$y.scales$limit
+        ylim <- foo$y.scales$limits
     }
 
     ## Step 4: Decide if log scales are being used:
@@ -378,7 +376,7 @@ histogram.formula <-
                     cond.max.level)
     }
 
-    more.comp <- c(limits.and.aspect(prepanel.default.histogram,
+    more.comp <- c(limits.and.aspect(default.prepanel,
                                      prepanel = prepanel, 
                                      have.xlim = have.xlim, xlim = xlim, 
                                      have.ylim = have.ylim, ylim = ylim, 
